@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 19 May 2012                                              }
 {*************************************************************************/
 
 #ifndef FSMAN_H
@@ -49,6 +49,10 @@ class FSMan : public QObject
     QString curDir;
     QDir dir;
 
+    bool searching;
+    QStringList searchDirs;
+    QRegExp searchRx;
+
     bool doFetchLists;
     bool doUseCache;
     bool doUseNativeMethods;
@@ -57,8 +61,9 @@ class FSMan : public QObject
     QStringList nameFilters;
 
     bool _cd();
-    void _fetch();
-    void _fetchForce();
+    void _fetch(const QString& _dir, QStringList& _dirs, QStringList& _files);
+    void _fetchForce(const QString& _dir, QStringList& _dirs, QStringList& _files);
+    void nextSearchStep();
 
 public:
     explicit FSMan(QObject *parent = 0);
@@ -94,9 +99,18 @@ public:
     static QString getShellCommandOutput(const QString& cmd);
     static QString shellEscape(const QString& line);
 
+    inline bool isSearching() const {return searching;}
+    void startSearch(const QString& expression, const QString startDir = "");
+    inline void stopSearch(){searching = false;}
+
 signals:
     void onFileFilter(bool *pass, const QString& basename, const QString& parentDir);
     void onDirFilter(bool *pass, const QString& basename, const QString& parentDir);
+    void onSearchResult(bool isDir, const QString& basename, const QString& parentDir);
+    void onSearchFinished();
+
+protected slots:
+    void onSearchStep();
 
 };
 
