@@ -34,83 +34,123 @@
         <translation>Сайт разработчика</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="45"/>
+        <location filename="../src/aboutwindow.cpp" line="46"/>
         <source>Compressed modules support</source>
         <translation>Поддержка сжатых модулей</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="47"/>
+        <location filename="../src/aboutwindow.cpp" line="48"/>
         <source>NO (install &apos;unzip&apos; package for this to work)</source>
         <translation>НЕТ (установите пакет &apos;unzip&apos;, для воспроизведения сжатой модульной музыки)</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="53"/>
+        <location filename="../src/aboutwindow.cpp" line="54"/>
         <source>NO (install &apos;%1&apos; gstreamer plugin to enable equalizer)</source>
         <translation>НЕТ (установите плагин для gstreamer &apos;%1&apos; чтобы добавить поддержку эквалайзера)</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="49"/>
-        <location filename="../src/aboutwindow.cpp" line="59"/>
+        <location filename="../src/aboutwindow.cpp" line="104"/>
+        <source>To stop a playback after a current track, do the following: check &quot;Let a current track to end before a stop by the timer&quot; option, then start a timer with a zero interval.</source>
+        <translation>Чтобы остановить воспроизведение после текущего трека, сделайте следующее: отметьте опцию &quot;Закончить текущий трек перед остановкой по таймеру&quot;, а затем запустите таймер с нулевым интервалом.</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="108"/>
+        <source>To stop a playback after the queue is empty, set &quot;Play mode&quot; to &quot;One track once&quot;.</source>
+        <translation>Чтобы остановить воспроизведение после того, как очередь закончилась, установите &quot;Режим воспроизведения&quot; в &quot;Один трек без повтора&quot;.</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="114"/>
+        <source>After you (un)install a new gstreamer plugin, you may click &quot;Select all supported&quot; button in &quot;File types&quot; window to update filters list.</source>
+        <translation>После того, как вы установили или удалили плагин для gstreamer, вы можете нажать на кнопку &quot;Выбрать все поддерживаемые&quot; в окне &quot;Типы файлов&quot;, чтобы обновить фильтры.</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="50"/>
+        <location filename="../src/aboutwindow.cpp" line="60"/>
         <source>YES</source>
         <translation>ДА</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="50"/>
+        <location filename="../src/aboutwindow.cpp" line="51"/>
         <source>Equalizer support</source>
         <translation>Поддержка эквалайзера</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="62"/>
+        <location filename="../src/aboutwindow.cpp" line="63"/>
         <source>To make more MIME types available, install appropriate gstreamer plugins</source>
         <translation>Устанавливайте соответствующие плагины для gstreamer, чтобы добавить поддержку новых форматов</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="61"/>
+        <location filename="../src/aboutwindow.cpp" line="62"/>
         <source>Supported MIME types</source>
         <translation>Поддерживаемые MIME типы</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="64"/>
+        <location filename="../src/aboutwindow.cpp" line="65"/>
         <source>Current skin</source>
         <translation>Текущий скин</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="43"/>
+        <location filename="../src/aboutwindow.cpp" line="44"/>
         <source>This project was inspired by %1.</source>
         <translation>Данный проект был вдохновлён %1.</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="72"/>
+        <location filename="../src/aboutwindow.cpp" line="73"/>
         <source>The README file for the current skin is either empty or not found.</source>
         <translation>Файл README текущего скина не найден либо пуст.</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="76"/>
+        <location filename="../src/aboutwindow.cpp" line="77"/>
         <source>The following is a contents of README file for a current skin:</source>
         <translation>Ниже приведено содержимое README файла текущего скина:</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="139"/>
+        <location filename="../src/aboutwindow.cpp" line="96"/>
+        <source>&quot;Hidden&quot; features</source>
+        <translation>&quot;Скрытые&quot; возможности</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="97"/>
+        <source>Folders and files have context menus. To invoke a context menu use a long press.</source>
+        <translation>У папок и файлов есть контекстное меню. Чтобы вызвать контекстное меню, используйте долгое нажатие.</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="100"/>
+        <source>You can search for a file by its name. Start typing to show a search window. A search will take place in a current folder and its subfolders.</source>
+        <translation>Вы можете искать файл по его имени. Начните набирать имя, чтобы открыть окно поиска. Поиск будет происходить в текущей папке и её подпапках.</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="111"/>
+        <source>In order to play compressed tracker music (*.xmz, *.s3z, ...) you must install &quot;unzip&quot;. This package can be found in &quot;extras-testing&quot; repository.</source>
+        <translation>Чтобы иметь возможность воспроизводить сжатую треккерную музыку (*.xmz, *.s3z, ...), вы должны установить &quot;unzip&quot;. Этот пакет может быть найден в репозитории &quot;extras-testing&quot;.</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="163"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="149"/>
+        <location filename="../src/aboutwindow.cpp" line="173"/>
         <source>App</source>
         <translation>Приложение</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="150"/>
+        <location filename="../src/aboutwindow.cpp" line="174"/>
         <source>System</source>
         <translation>Система</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="151"/>
+        <location filename="../src/aboutwindow.cpp" line="175"/>
         <source>Skin</source>
         <translation>Скин</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="152"/>
+        <location filename="../src/aboutwindow.cpp" line="176"/>
+        <source>Tips</source>
+        <translation>Подсказки</translation>
+    </message>
+    <message>
+        <location filename="../src/aboutwindow.cpp" line="43"/>
         <source>License</source>
         <translation>Лицензия</translation>
     </message>
@@ -118,140 +158,140 @@
 <context>
     <name>EqualizerWindow</name>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="58"/>
+        <location filename="../src/equalizerwindow.cpp" line="57"/>
         <source>Equalizer</source>
         <translation>Эквалайзер</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="34"/>
+        <location filename="../src/equalizerwindow.cpp" line="33"/>
         <source>off</source>
         <comment>presetLabel</comment>
         <translation>выкл.</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="95"/>
+        <location filename="../src/equalizerwindow.cpp" line="94"/>
         <source>Hz</source>
         <translation>Гц</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="105"/>
+        <location filename="../src/equalizerwindow.cpp" line="104"/>
         <source>kHz</source>
         <translation>кГц</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="242"/>
+        <location filename="../src/equalizerwindow.cpp" line="221"/>
         <source>dB</source>
         <translation>дБ</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="262"/>
+        <location filename="../src/equalizerwindow.cpp" line="241"/>
         <source>Preset</source>
         <translation>Пресет</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="304"/>
+        <location filename="../src/equalizerwindow.cpp" line="283"/>
         <source>Save changes</source>
         <translation>Сохранить изменения</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="305"/>
+        <location filename="../src/equalizerwindow.cpp" line="284"/>
         <source>The current preset was modified. Do you want to apply changes?</source>
         <translation>Текущий пресет был изменён. Вы хотите применить изменения?</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="331"/>
-        <location filename="../src/equalizerwindow.cpp" line="342"/>
-        <location filename="../src/equalizerwindow.cpp" line="351"/>
+        <location filename="../src/equalizerwindow.cpp" line="315"/>
+        <location filename="../src/equalizerwindow.cpp" line="326"/>
+        <location filename="../src/equalizerwindow.cpp" line="335"/>
         <source>New preset</source>
         <translation>Новый пресет</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="332"/>
+        <location filename="../src/equalizerwindow.cpp" line="316"/>
         <source>Enter a name for a new preset</source>
         <translation>Введите название нового пресета</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="343"/>
-        <location filename="../src/equalizerwindow.cpp" line="402"/>
+        <location filename="../src/equalizerwindow.cpp" line="327"/>
+        <location filename="../src/equalizerwindow.cpp" line="386"/>
         <source>Preset name cannot be empty!</source>
         <translation>Название пресета не может быть пустым!</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="352"/>
+        <location filename="../src/equalizerwindow.cpp" line="336"/>
         <source>Preset with such name already exists!</source>
         <translation>Пресет с таким именем уже существует!</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="364"/>
+        <location filename="../src/equalizerwindow.cpp" line="348"/>
         <source>New preset has been created and selected</source>
         <translation>Новый пресет был создан и выбран</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="376"/>
-        <location filename="../src/equalizerwindow.cpp" line="388"/>
-        <location filename="../src/equalizerwindow.cpp" line="401"/>
-        <location filename="../src/equalizerwindow.cpp" line="410"/>
+        <location filename="../src/equalizerwindow.cpp" line="360"/>
+        <location filename="../src/equalizerwindow.cpp" line="372"/>
+        <location filename="../src/equalizerwindow.cpp" line="385"/>
+        <location filename="../src/equalizerwindow.cpp" line="394"/>
         <source>Rename the preset</source>
         <translation>Переименовать пресет</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="377"/>
+        <location filename="../src/equalizerwindow.cpp" line="361"/>
         <source>This is a system preset, therefore it cannot be renamed.</source>
         <translation>Это системный пресет, поэтому он не может быть переименован.</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="389"/>
+        <location filename="../src/equalizerwindow.cpp" line="373"/>
         <source>Enter a new name for the current preset</source>
         <translation>Введите новое название для текущего пресета</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="411"/>
+        <location filename="../src/equalizerwindow.cpp" line="395"/>
         <source>There is another preset with such name!</source>
         <translation>Такое название уже есть у другого пресета!</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="419"/>
+        <location filename="../src/equalizerwindow.cpp" line="403"/>
         <source>The current preset has been renamed</source>
         <translation>Текущий пресет был переименован</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="430"/>
+        <location filename="../src/equalizerwindow.cpp" line="414"/>
         <source>Save the preset</source>
         <translation>Сохранить пресет</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="431"/>
+        <location filename="../src/equalizerwindow.cpp" line="415"/>
         <source>This is a system preset, therefore it cannot be saved.</source>
         <translation>Это системный пресет, поэтому он не может быть сохранён.</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="436"/>
+        <location filename="../src/equalizerwindow.cpp" line="420"/>
         <source>The current preset has been updated</source>
         <translation>Текущий пресет был обновлён</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="446"/>
-        <location filename="../src/equalizerwindow.cpp" line="453"/>
+        <location filename="../src/equalizerwindow.cpp" line="430"/>
+        <location filename="../src/equalizerwindow.cpp" line="437"/>
         <source>Delete the preset</source>
         <translation>Удалить пресет</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="447"/>
+        <location filename="../src/equalizerwindow.cpp" line="431"/>
         <source>This is a system preset, therefore it cannot be deleted.</source>
         <translation>Это системный пресет, поэтому он не может быть удалён.</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="454"/>
+        <location filename="../src/equalizerwindow.cpp" line="438"/>
         <source>Are you sure you want to delete the current preset?</source>
         <translation>Вы уверены, что хотите удалить текущий пресет?</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="464"/>
+        <location filename="../src/equalizerwindow.cpp" line="448"/>
         <source>The current preset has been deleted</source>
         <translation>Текущий пресет был удалён</translation>
     </message>
     <message>
-        <location filename="../src/equalizerwindow.cpp" line="476"/>
+        <location filename="../src/equalizerwindow.cpp" line="460"/>
         <source>Select a preset</source>
         <translation>Выберите пресет</translation>
     </message>
@@ -304,22 +344,22 @@
         <translation>Добавить этот файл в очередь</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="824"/>
+        <location filename="../src/mainwindow.cpp" line="864"/>
         <source>Cache has been cleared</source>
         <translation>Кэш очищен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="884"/>
+        <location filename="../src/mainwindow.cpp" line="918"/>
         <source>Equalizer module not found!</source>
         <translation>Модуль эквалайзера не найден!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="901"/>
+        <location filename="../src/mainwindow.cpp" line="935"/>
         <source>The timer has been started</source>
         <translation>Таймер запущен</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="951"/>
+        <location filename="../src/mainwindow.cpp" line="983"/>
         <source>added %n more file(s)</source>
         <translation>
             <numerusform>добавлен ещё %n файл</numerusform>
@@ -328,58 +368,58 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="949"/>
+        <location filename="../src/mainwindow.cpp" line="981"/>
         <source>total files count</source>
         <translation>общее число файлов</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="953"/>
+        <location filename="../src/mainwindow.cpp" line="985"/>
         <source>no new files added</source>
         <translation>новых файлов не добавлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="968"/>
+        <location filename="../src/mainwindow.cpp" line="1000"/>
         <source>this file will be played next</source>
         <translation>этот файл будет проигран следующим</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="977"/>
+        <location filename="../src/mainwindow.cpp" line="1009"/>
         <source>files queued</source>
         <translation>файлов в очереди</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="978"/>
+        <location filename="../src/mainwindow.cpp" line="1010"/>
         <source>this file has been added to queue</source>
         <translation>этот файл был добавлен в очередь</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1146"/>
+        <location filename="../src/mainwindow.cpp" line="1185"/>
         <source>off</source>
         <comment>eqActionLabel</comment>
         <translation>выкл.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1149"/>
+        <location filename="../src/mainwindow.cpp" line="1188"/>
         <source>Equalizer</source>
         <translation>Эквалайзер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1240"/>
+        <location filename="../src/mainwindow.cpp" line="1279"/>
         <source>Playback has been stopped</source>
         <translation>Воспроизведение остановлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1266"/>
+        <location filename="../src/mainwindow.cpp" line="1336"/>
         <source>Timer has been stopped</source>
         <translation>Таймер остановлен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1278"/>
+        <location filename="../src/mainwindow.cpp" line="1348"/>
         <source>Timer</source>
         <translation>Таймер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1282"/>
+        <location filename="../src/mainwindow.cpp" line="1352"/>
         <source>off</source>
         <translation>выкл.</translation>
     </message>
@@ -389,13 +429,13 @@
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="922"/>
-        <location filename="../src/mainwindow.cpp" line="939"/>
+        <location filename="../src/mainwindow.cpp" line="956"/>
+        <location filename="../src/mainwindow.cpp" line="972"/>
         <source>searching...</source>
         <translation>ищем...</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="928"/>
+        <location filename="../src/mainwindow.cpp" line="961"/>
         <source>found %n file(s)</source>
         <translation>
             <numerusform>нашёлся %n файл</numerusform>
@@ -558,6 +598,29 @@
         <translation>Ориентация экрана</translation>
     </message>
 </context>
+<context>
+    <name>SearchWindow</name>
+    <message>
+        <location filename="../src/searchwindow.cpp" line="67"/>
+        <source>Search for files and folders</source>
+        <translation>Искать файлы и папки</translation>
+    </message>
+    <message>
+        <location filename="../src/searchwindow.cpp" line="77"/>
+        <source>nothing&apos;s found</source>
+        <translation>ничего не найдено</translation>
+    </message>
+    <message>
+        <location filename="../src/searchwindow.cpp" line="144"/>
+        <source>search</source>
+        <translation>поиск</translation>
+    </message>
+    <message>
+        <location filename="../src/searchwindow.cpp" line="176"/>
+        <source>stop</source>
+        <translation>стоп</translation>
+    </message>
+</context>
 <context>
     <name>TimerWindow</name>
     <message>
@@ -588,5 +651,10 @@
         <source>Displayed file types</source>
         <translation>Отображаемые типы файлов</translation>
     </message>
+    <message>
+        <location filename="../src/typeswindow.cpp" line="121"/>
+        <source>Select all supported</source>
+        <translation>Выбрать все поддерживаемые</translation>
+    </message>
 </context>
 </TS>
